# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserAllowedRemedyReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserAllowedRemedyReq(object):
    employee_type: GetAttendanceUserAllowedRemedyReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserAllowedRemedyReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 的员工工号类型，必选字段，可用值：【employee_id（员工employeeId），employee_no（员工工号）】，示例值："employee_id"
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    remedy_date: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询补卡的日期


@attr.s
class GetAttendanceUserAllowedRemedyRespUserAllowedRemedys(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    remedy_date: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡日期
    is_free_punch: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为自由班次，若为自由班次，则不用选择考虑第几次上下班，直接选择补卡时间即可
    punch_no: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 第几次上下班，可用值：【0（第 1 次上下班），1（第 2 次上下班），2（第 3 次上下班）】
    work_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 上班/下班，1：上班，2：下班
    punch_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡状态，可用值【Early（早退），Late（迟到），Lack（缺卡）】
    normal_punch_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 正常的应打卡时间，时间格式为 yyyy-MM-dd HH:mm
    remedy_start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可选的补卡时间的最小值，时间格式为 yyyy-MM-dd HH:mm
    remedy_end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可选的补卡时间的最大值，时间格式为 yyyy-MM-dd HH:mm


@attr.s
class GetAttendanceUserAllowedRemedyResp(object):
    user_allowed_remedys: GetAttendanceUserAllowedRemedyRespUserAllowedRemedys = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )


def _gen_get_attendance_user_allowed_remedy_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserAllowedRemedyResp,
        scope="Attendance",
        api="GetAttendanceUserAllowedRemedy",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_task_remedys/query_user_allowed_remedys",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateBitableViewReq(object):
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblsRc9GRRXKqhvW"
    view_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图Id, 示例值："vewTpR1urY"
    view_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图名字, 示例值："甘特视图1"
    view_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图类型, 示例值："gantt"


@attr.s
class CreateBitableViewRespApptableview(object):
    view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 视图Id
    view_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 视图名字
    view_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 视图类型


@attr.s
class CreateBitableViewResp(object):
    view: CreateBitableViewRespApptableview = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 视图


def _gen_create_bitable_view_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateBitableViewResp,
        scope="Bitable",
        api="CreateBitableView",
        method="POST",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/views",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class ReplyMeetingRoomInstanceReq(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室的 ID
    uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室的日程 ID
    original_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程实例原始时间，非重复日程必为0。重复日程若为0则表示回复其所有实例，否则表示回复单个实例。
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复状态，NOT_CHECK_IN 表示未签到，ENDED_BEFORE_DUE 表示提前结束


@attr.s
class ReplyMeetingRoomInstanceResp(object):
    pass


def _gen_reply_meeting_room_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=ReplyMeetingRoomInstanceResp,
        scope="MeetingRoom",
        api="ReplyMeetingRoomInstance",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/instance/reply",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待撤回的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"


@attr.s
class DeleteMessageResp(object):
    pass


def _gen_delete_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteMessageResp,
        scope="Message",
        api="DeleteMessage",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveMemberPermissionListReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型   "doc"  or  "sheet" or "bitable"  or "file"


@attr.s
class GetDriveMemberPermissionListRespMember(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 协作者类型 "user" or "chat"
    member_open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 协作者openid
    member_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 协作者userid(仅当member_type="user"时有效)
    perm: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 协作者权限 (注意: **有"edit"权限的协作者一定有"view"权限**)


@attr.s
class GetDriveMemberPermissionListResp(object):
    members: typing.List[GetDriveMemberPermissionListRespMember] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 协作者列表


def _gen_get_drive_member_permission_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveMemberPermissionListResp,
        scope="Drive",
        api="GetDriveMemberPermissionList",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/member/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DownloadAttendanceFileReq(object):
    file_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件 ID，示例值："xxxxxb306842b1c189bc5212eefxxxxx"


@attr.s
class DownloadAttendanceFileRespFile(object):
    pass


@attr.s
class DownloadAttendanceFileResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"resp_type": "header"}
    )
    filename: str = attr.ib(default="", metadata={"resp_type": "header"})  # 文件名


@attr.s
class DownloadAttendanceFileResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"resp_type": "header"})
    code: int = attr.ib(default=0, metadata={"resp_type": "header"})
    msg: str = attr.ib(default="", metadata={"resp_type": "header"})
    data: DownloadAttendanceFileResp = attr.ib(
        default=None, metadata={"resp_type": "header"}
    )


def _gen_download_attendance_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DownloadAttendanceFileResp,
        scope="Attendance",
        api="DownloadAttendanceFile",
        method="GET",
        url="https://open.feishu.cn/open-apis/attendance/v1/files/:file_id/download",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteDepartmentReqDepartmentIDType(object):
    pass


@attr.s
class DeleteDepartmentReq(object):
    department_id_type: DeleteDepartmentReqDepartmentIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 此次调用中使用的部门ID的类型, 示例值："open_department_id", 可选值有: `department_id`：以自定义department_id来标识部门, `open_department_id`：以open_department_id来标识部门, 默认值: `open_department_id`
    department_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 部门ID，需要与查询参数中传入的department_id_type类型保持一致。, 示例值："od-4e6ac4d14bcd5071a37a39de902c7141", 最大长度：`128` 字符, 正则校验：`^0|[^od][A-Za-z0-9]*`


@attr.s
class DeleteDepartmentResp(object):
    pass


def _gen_delete_department_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteDepartmentResp,
        scope="Contact",
        api="DeleteDepartment",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/contact/v3/departments/:department_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class RecognizeSpeechFileReqConfig(object):
    file_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 仅包含字母数字和下划线的 16 位字符串作为文件的标识，用户生成, 示例值："qwe12dd34567890w"
    format: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 语音格式，目前仅支持：pcm, 示例值："pcm"
    engine_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 引擎类型，目前仅支持：16k_auto 中英混合, 示例值："16k_auto"


@attr.s
class RecognizeSpeechFileReqSpeech(object):
    speech: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # base64 后的音频文件进行, 示例值："base64 后的音频内容"


@attr.s
class RecognizeSpeechFileReq(object):
    speech: RecognizeSpeechFileReqSpeech = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 语音资源
    config: RecognizeSpeechFileReqConfig = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 配置属性


@attr.s
class RecognizeSpeechFileResp(object):
    recognition_text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 语音识别后的文本信息


def _gen_recognize_speech_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=RecognizeSpeechFileResp,
        scope="AI",
        api="RecognizeSpeechFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/speech_to_text/v1/speech/file_recognize",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveFileMetaReqRequestDocs(object):
    docs_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见[概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    docs_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件类型  <br>1) "doc": 飞书文档<br>2) "sheet": 飞书电子表格 <br>3) "bitable": 飞书多维表格<br>4) "mindnote": 飞书思维笔记 <br>5) "file": 飞书文件


@attr.s
class GetDriveFileMetaReq(object):
    request_docs: GetDriveFileMetaReqRequestDocs = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 请求文档，一次不超过200个


@attr.s
class GetDriveFileMetaRespDocsMetas(object):
    docs_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件token
    docs_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题
    owner_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件拥有者
    create_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 创建时间（Unix时间戳）
    latest_modify_user: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 最后编辑者
    latest_modify_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 最后编辑时间（Unix时间戳）


@attr.s
class GetDriveFileMetaResp(object):
    docs_metas: GetDriveFileMetaRespDocsMetas = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件元数据


def _gen_get_drive_file_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveFileMetaResp,
        scope="Drive",
        api="GetDriveFileMeta",
        method="POST",
        url="https://open.feishu.cn/open-apis/suite/docs-api/meta",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetChatListOfSelfReqUserIDType(object):
    pass


@attr.s
class GetChatListOfSelfReq(object):
    user_id_type: GetChatListOfSelfReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："dmJCRHhpd3JRbGV1VEVNRFFyTitRWDY5ZFkybmYrMEUwMUFYT0VMMWdENEtuYUhsNUxGMDIwemtvdE5ORjBNQQ=="
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`


@attr.s
class GetChatListOfSelfRespItemOwnerIDType(object):
    pass


@attr.s
class GetChatListOfSelfRespItem(object):
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 群组 ID
    avatar: str = attr.ib(default="", metadata={"req_type": "json"})  # 群头像 URL
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 群名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 群描述
    owner_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 群主 ID
    owner_id_type: GetChatListOfSelfRespItemOwnerIDType = attr.ib(
        factory=lambda: GetChatListOfSelfRespItemOwnerIDType(),
        metadata={"req_type": "json"},
    )  # 群主 ID 类型


@attr.s
class GetChatListOfSelfResp(object):
    items: typing.List[GetChatListOfSelfRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # chat 列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_chat_list_of_self_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetChatListOfSelfResp,
        scope="Chat",
        api="GetChatListOfSelf",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSheetDataValidationDropdownReq(object):
    range_: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    data_validation_type: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 下拉列表填"list"
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class GetSheetDataValidationDropdownRespDataValidationOptionsColorValueMap(object):
    pass


@attr.s
class GetSheetDataValidationDropdownRespDataValidationOptions(object):
    multiple_values: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单选填false, 多选填true
    highlight_valid_data: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否设置颜色和胶囊样式
    color_value_map: GetSheetDataValidationDropdownRespDataValidationOptionsColorValueMap = attr.ib(
        factory=lambda: GetSheetDataValidationDropdownRespDataValidationOptionsColorValueMap(),
        metadata={"req_type": "json"},
    )  # 当highlightValidData为true时，colorValueMap的key与conditionValues中的值一一对应，value为对应的颜色参数。


@attr.s
class GetSheetDataValidationDropdownRespDataValidation(object):
    data_validation_id: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 唯一标示id
    data_validation_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下拉列表为"list"
    condition_values: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 下拉列表选项值
    options: GetSheetDataValidationDropdownRespDataValidationOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可选属性


@attr.s
class GetSheetDataValidationDropdownResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet的token
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作表 sheet 的 id
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 版本号
    data_validations: typing.List[
        GetSheetDataValidationDropdownRespDataValidation
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 下拉列表数组, 不存在时为空


def _gen_get_sheet_data_validation_dropdown_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSheetDataValidationDropdownResp,
        scope="Drive",
        api="GetSheetDataValidationDropdown",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dataValidation",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateDriveCommentReqContentElementPerson(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 at联系人, 示例值："ou_cc19b2bfb93f8a44db4b4d6eab*****"


@attr.s
class UpdateDriveCommentReqContentElementDocsLink(object):
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 at云文档, 示例值："https://bytedance.feishu.cn/docs/doccnHh7U87HOFpii5u5G*****"


@attr.s
class UpdateDriveCommentReqContentElementTextRun(object):
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 普通文本, 示例值："comment text"


@attr.s
class UpdateDriveCommentReqContentElement(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复的内容元素, 示例值："text_run", 可选值有: `text_run`：普通文本, `docs_link`：at 云文档链接, `person`：at 联系人
    text_run: UpdateDriveCommentReqContentElementTextRun = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    docs_link: UpdateDriveCommentReqContentElementDocsLink = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    person: UpdateDriveCommentReqContentElementPerson = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容


@attr.s
class UpdateDriveCommentReqContent(object):
    elements: typing.List[UpdateDriveCommentReqContentElement] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复的内容


@attr.s
class UpdateDriveCommentReqFileType(object):
    pass


@attr.s
class UpdateDriveCommentReq(object):
    file_type: UpdateDriveCommentReqFileType = attr.ib(
        factory=lambda: UpdateDriveCommentReqFileType(), metadata={"req_type": "query"}
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnHh7U87HOFpii5u5G*****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 评论ID, 示例值："6916106822734578184"
    reply_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 回复ID, 示例值："6916106822734594568"
    content: UpdateDriveCommentReqContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 回复内容


@attr.s
class UpdateDriveCommentResp(object):
    pass


def _gen_update_drive_comment_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateDriveCommentResp,
        scope="Drive",
        api="UpdateDriveComment",
        method="PUT",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments/:comment_id/replies/:reply_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchCreateAttendanceUserFlowReqFlowRecord(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    creator_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡记录创建者的工号
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡位置名称信息
    check_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡时间，精确到秒的时间戳
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡备注


@attr.s
class BatchCreateAttendanceUserFlowReqEmployeeType(object):
    pass


@attr.s
class BatchCreateAttendanceUserFlowReq(object):
    employee_type: BatchCreateAttendanceUserFlowReqEmployeeType = attr.ib(
        factory=lambda: BatchCreateAttendanceUserFlowReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 和 creator_id 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值："employee_id"
    flow_records: typing.List[BatchCreateAttendanceUserFlowReqFlowRecord] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡流水记录列表


@attr.s
class BatchCreateAttendanceUserFlowRespFlowRecord(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    creator_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡记录创建者的 employee_no
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡位置名称信息
    check_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡时间，精确到秒的时间戳
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡备注


@attr.s
class BatchCreateAttendanceUserFlowResp(object):
    flow_records: typing.List[BatchCreateAttendanceUserFlowRespFlowRecord] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡流水记录列表


def _gen_batch_create_attendance_user_flow_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchCreateAttendanceUserFlowResp,
        scope="Attendance",
        api="BatchCreateAttendanceUserFlow",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_flows/batch_create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenCalenderEventCreateReq(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始日期，{unixTime}格式
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束日期，{unixTime}格式
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程主题，中文可使用encodeURIComponent方法生成


@attr.s
class OpenCalenderEventCreateResp(object):
    pass


def _gen_open_calender_event_create_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenCalenderEventCreateResp,
        scope="AppLink",
        api="OpenCalenderEventCreate",
        method="",
        url="https://applink.feishu.cn/client/calendar/event/create",
        body=request,
        method_option=_new_method_option(options),
    )



import attr
import typing


@attr.s
class MessageContentPostItem(object):
    pass


@attr.s
class MessageContentPost(object):
    title = attr.ib(default="")
    content: typing.List[typing.List[MessageContentPostItem]] = attr.ib(
        factory=lambda: []
    )


@attr.s
class MessageContentPostAll(object):
    zh_cn: MessageContentPost = attr.ib(default=None)
    ja_jp: MessageContentPost = attr.ib(default=None)
    en_us: MessageContentPost = attr.ib(default=None)


# type MessageContentPostText struct {
# 	messageContentPostInterfaceDefaultImpl
# 	Text     string `json:"text"`      // 文本内容
# 	UnEscape bool   `json:"un_escape"` // 表示是不是 unescape 解码，默认为 false ，不用可以不填
# }
#
# func (r MessageContentPostText) MarshalJSON() ([]byte, error) {
# 	return json.Marshal(map[string]interface{}{
# 		"text":      r.Text,
# 		"un_escape": r.UnEscape,
# 		"tag":       "text",
# 	})
# }
#
# type MessageContentPostLink struct {
# 	messageContentPostInterfaceDefaultImpl
# 	Text     string `json:"text"`      // 文本内容
# 	UnEscape bool   `json:"un_escape"` //
# 	Href     string `json:"href"`      // 默认的链接地址
# }
#
# func (r MessageContentPostLink) MarshalJSON() ([]byte, error) {
# 	return json.Marshal(map[string]interface{}{
# 		"text":      r.Text,
# 		"un_escape": r.UnEscape,
# 		"href":      r.Href,
# 		"tag":       "a",
# 	})
# }
#
# type MessageContentPostAt struct {
# 	messageContentPostInterfaceDefaultImpl
# 	UserID   string `json:"user_id"`   // open_id
# 	UserName string `json:"user_name"` // 用户姓名
# }
#
# func (r MessageContentPostAt) MarshalJSON() ([]byte, error) {
# 	v := map[string]interface{}{
# 		"user_id": r.UserID,
# 		"tag":     "at",
# 	}
# 	if r.UserName != "" {
# 		v["user_name"] = r.UserName
# 	}
# 	return json.Marshal(v)
# }
#
# type MessageContentPostImage struct {
# 	messageContentPostInterfaceDefaultImpl
# 	ImageKey string `json:"image_key"` // 图片的唯一标识
# 	Height   int    `json:"height"`    // 图片的高
# 	Width    int    `json:"width"`     // 图片的宽
# }
#
# func (r MessageContentPostImage) MarshalJSON() ([]byte, error) {
# 	return json.Marshal(map[string]interface{}{
# 		"image_key": r.ImageKey,
# 		"height":    r.Height,
# 		"width":     r.Width,
# 		"tag":       "img",
# 	})
# }
#
# type messageContentPostInterfaceDefaultImpl struct{}
#
# func (r messageContentPostInterfaceDefaultImpl) IsMessageContentPostItem() bool {
# 	return true
# }



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskTicketReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # ticket id, 示例值："123456"


@attr.s
class GetHelpdeskTicketRespTicketAgentServiceDuration(object):
    pass


@attr.s
class GetHelpdeskTicketRespTicketCustomizedField(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段值
    key_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 键名
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 展示名称
    position: int = attr.ib(default=0, metadata={"req_type": "json"})  # 展示位置
    required: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否必填
    editable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可修改


@attr.s
class GetHelpdeskTicketRespTicketCollaborator(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 所在部门名称


@attr.s
class GetHelpdeskTicketRespTicketClosedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 所在部门名称


@attr.s
class GetHelpdeskTicketRespTicketAgent(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 所在部门名称


@attr.s
class GetHelpdeskTicketRespTicketGuest(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 所在部门名称


@attr.s
class GetHelpdeskTicketRespTicket(object):
    ticket_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工单ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    guest: GetHelpdeskTicketRespTicketGuest = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工单创建用户
    stage: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单阶段，1：bot，2：人工
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单状态，1：已创建 2: 处理中 3: 排队中 4：待定 5：待用户响应 50: 被机器人关闭 51: 被人工关闭
    score: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单评分，1：不满意，2:一般，3:满意
    created_at: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单创建时间
    updated_at: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单更新时间，没有值时为-1
    closed_at: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单结束时间
    agents: typing.List[GetHelpdeskTicketRespTicketAgent] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单客服
    channel: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单渠道
    solve: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单是否解决 1:没解决 2:已解决
    closed_by: GetHelpdeskTicketRespTicketClosedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 关单用户ID
    collaborators: typing.List[GetHelpdeskTicketRespTicketCollaborator] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单协作者
    customized_fields: typing.List[
        GetHelpdeskTicketRespTicketCustomizedField
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段列表，没有值时不设置
    agent_service_duration: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 客服服务时长minutes
    agent_first_response_duration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 客服第一反应时间 seconds
    bot_service_duration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 机器人服务时长 seconds
    agent_resolution_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 解决时长(秒)
    actual_processing_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 处理时长(秒)


@attr.s
class GetHelpdeskTicketResp(object):
    ticket: GetHelpdeskTicketRespTicket = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工单详情


def _gen_get_helpdesk_ticket_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskTicketResp,
        scope="Helpdesk",
        api="GetHelpdeskTicket",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets/:ticket_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBitableRecordReq(object):
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："bascnCMII2ORej2RItqpZZUNMIe"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblxI2tWaxP5dG7p"
    record_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 单条记录的 id, 示例值："recn0hoyXL"


@attr.s
class GetBitableRecordRespRecordFieldsValue(object):
    pass


@attr.s
class GetBitableRecordRespRecordFields(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名
    value: typing.Any = attr.ib(default=None, metadata={"req_type": "json"})  # 内容


@attr.s
class GetBitableRecordRespRecord(object):
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 记录 id
    fields: GetBitableRecordRespRecordFields = attr.ib(
        factory=lambda: GetBitableRecordRespRecordFields(),
        metadata={"req_type": "json"},
    )  # 记录字段


@attr.s
class GetBitableRecordResp(object):
    record: GetBitableRecordRespRecord = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 记录


def _gen_get_bitable_record_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBitableRecordResp,
        scope="Bitable",
        api="GetBitableRecord",
        method="GET",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/records/:record_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteCalendarEventAttendeeReq(object):
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历 ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    event_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日程 ID, 示例值："xxxxxxxxx_0"
    attendee_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 要移除的参与人 ID 列表
    need_notification: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 删除日程参与人时是否要给参与人发送bot通知，默认为true, 示例值：false


@attr.s
class DeleteCalendarEventAttendeeResp(object):
    pass


def _gen_delete_calendar_event_attendee_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteCalendarEventAttendeeResp,
        scope="Calendar",
        api="DeleteCalendarEventAttendee",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/events/:event_id/attendees/batch_delete",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UncompleteTaskReq(object):
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："bb54ab99-d360-434f-bcaa-a4cc4c05840e"


@attr.s
class UncompleteTaskResp(object):
    pass


def _gen_uncomplete_task_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UncompleteTaskResp,
        scope="Task",
        api="UncompleteTask",
        method="POST",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/uncomplete",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetACSDeviceListReq(object):
    pass


@attr.s
class GetACSDeviceListRespItem(object):
    device_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 门禁设备 ID
    device_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 设备名称
    device_sn: str = attr.ib(default="", metadata={"req_type": "json"})  # 设备 SN 码


@attr.s
class GetACSDeviceListResp(object):
    items: typing.List[GetACSDeviceListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # -


def _gen_get_acs_device_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetACSDeviceListResp,
        scope="ACS",
        api="GetACSDeviceList",
        method="GET",
        url="https://open.feishu.cn/open-apis/acs/v1/devices",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateBitableFieldReqPropertyOption(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项名, 示例值："红色"
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 选项id, 示例值："optKl35lnG"


@attr.s
class CreateBitableFieldReqProperty(object):
    options: typing.List[CreateBitableFieldReqPropertyOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 单选/多选字段的选项信息
    formatter: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 数字字段的数字显示格式, 示例值："0"
    date_format: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日期格式, 示例值："yyyy/MM/dd"
    time_format: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 时间格式, 示例值："HH:mm"
    auto_fill: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否自动填入创建时间, 示例值：false
    multiple: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 多选标记, 示例值：false
    table_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 关联字段中关联表的id, 示例值："tblsRc9GRRXKqhvW"
    view_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 关联字段中关联表的视图id, 示例值："vewOVMEXPF"
    fields: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联字段要展示的字段, 示例值：["fldSiTwIqy"]


@attr.s
class CreateBitableFieldReqUserIDType(object):
    pass


@attr.s
class CreateBitableFieldReq(object):
    user_id_type: CreateBitableFieldReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblsRc9GRRXKqhvW"
    field_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 多维表格字段名, 示例值："多行文本"
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 多维表格字段类型, 示例值：1
    property: CreateBitableFieldReqProperty = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段属性, 具体参考: [Property说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/bitable/development-guide/bitable-structure#b286b4ee)


@attr.s
class CreateBitableFieldRespFieldPropertyOption(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项名
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项id


@attr.s
class CreateBitableFieldRespFieldProperty(object):
    options: typing.List[CreateBitableFieldRespFieldPropertyOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 单选/多选字段的选项信息
    formatter: str = attr.ib(default="", metadata={"req_type": "json"})  # 数字字段的数字显示格式
    date_format: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期格式
    time_format: str = attr.ib(default="", metadata={"req_type": "json"})  # 时间格式
    auto_fill: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否自动填入创建时间
    multiple: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 多选标记
    table_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 关联字段中关联表的id
    view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 关联字段中关联表的视图id
    fields: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联字段要展示的字段


@attr.s
class CreateBitableFieldRespField(object):
    field_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 多维表格字段 id
    field_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 多维表格字段名
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 多维表格字段类型
    property: CreateBitableFieldRespFieldProperty = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段属性, 具体参考: [Property说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/bitable/development-guide/bitable-structure#b286b4ee)


@attr.s
class CreateBitableFieldResp(object):
    field: CreateBitableFieldRespField = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段


def _gen_create_bitable_field_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateBitableFieldResp,
        scope="Bitable",
        api="CreateBitableField",
        method="POST",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/fields",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHelpdeskAgentReq(object):
    agent_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 客服id, 示例值："ou_14777d82ffef0f707de5a8c7ff2c5ebe"
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # agent status, 示例值：1：在线；2：离线


@attr.s
class UpdateHelpdeskAgentResp(object):
    pass


def _gen_update_helpdesk_agent_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHelpdeskAgentResp,
        scope="Helpdesk",
        api="UpdateHelpdeskAgent",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agents/:agent_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SubscribeCalendarReq(object):
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"


@attr.s
class SubscribeCalendarRespCalendarRole(object):
    pass


@attr.s
class SubscribeCalendarRespCalendarType(object):
    pass


@attr.s
class SubscribeCalendarRespCalendarPermissions(object):
    pass


@attr.s
class SubscribeCalendarRespCalendar(object):
    calendar_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 日历ID
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日历标题, 最大长度：`255` 字符
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日历描述, 最大长度：`255` 字符
    permissions: SubscribeCalendarRespCalendarPermissions = attr.ib(
        factory=lambda: SubscribeCalendarRespCalendarPermissions(),
        metadata={"req_type": "json"},
    )  # 日历公开范围, 可选值有: `private`：私密, `show_only_free_busy`：仅展示忙闲信息, `public`：他人可查看日程详情
    color: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日历颜色，颜色RGB值的int32表示。客户端展示时会映射到色板上最接近的一种颜色。仅对当前身份生效
    type: SubscribeCalendarRespCalendarType = attr.ib(
        factory=lambda: SubscribeCalendarRespCalendarType(),
        metadata={"req_type": "json"},
    )  # 日历类型, 可选值有: `unknown`：未知类型, `primary`：用户或应用的主日历, `shared`：由用户或应用创建的共享日历, `google`：用户绑定的谷歌日历, `resource`：会议室日历, `exchange`：用户绑定的Exchange日历
    summary_alias: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日历备注名，修改或添加后仅对当前身份生效, 最大长度：`255` 字符
    is_deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 对于当前身份，日历是否已经被标记为删除, 默认值: `false`
    is_third_party: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 当前日历是否是第三方数据；三方日历及日程只支持读，不支持写入, 默认值: `false`
    role: SubscribeCalendarRespCalendarRole = attr.ib(
        factory=lambda: SubscribeCalendarRespCalendarRole(),
        metadata={"req_type": "json"},
    )  # 当前身份对于该日历的访问权限, 可选值有: `unknown`：未知权限, `free_busy_reader`：游客，只能看到忙碌/空闲信息, `reader`：订阅者，查看所有日程详情, `writer`：编辑者，创建及修改日程, `owner`：管理员，管理日历及共享设置


@attr.s
class SubscribeCalendarResp(object):
    calendar: SubscribeCalendarRespCalendar = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 订阅的日历实体


def _gen_subscribe_calendar_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SubscribeCalendarResp,
        scope="Calendar",
        api="SubscribeCalendar",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/subscribe",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SetSheetValueImageReqImage(object):
    pass


@attr.s
class SetSheetValueImageReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet的token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询范围  range=<sheetId>!<开始格子>:<结束格子> 如：xxxx!A1:D5，详见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)。此处限定为一个格子，如: xxxx!A1:A1
    image: typing.List[SetSheetValueImageReqImage] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 需要写入的图片二进制流，支持  "PNG", "JPEG", "JPG", "GIF", "BMP", "JFIF", "EXIF", "TIFF", "BPG", "WEBP", "HEIC" 等图片格式
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 写入的图片名字


@attr.s
class SetSheetValueImageResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token


def _gen_set_sheet_value_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SetSheetValueImageResp,
        scope="Drive",
        api="SetSheetValueImage",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/values_image",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateHelpdeskAgentSkillReqRule(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # rule id, 看[获取客服技能rules](https://open.feishu.cn/document/ukTMukTMukTM/ucDOyYjL3gjM24yN4IjN/list-agent-skill-rules) 用于获取rules options, 示例值："test-skill-id"
    selected_operator: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 运算符compare, 看[客服技能运算符options](https://open.feishu.cn/document/ukTMukTMukTM/ucDOyYjL3gjM24yN4IjN/operator-options), 示例值：3
    operand: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # rule操作数value, 示例值："    {,                    "selected": ["6883005079188668418"],,                    "options": [,                        {,                            "id": "6883005079188668418",,                            "name": {,                                "en_us": "小程序及应用",,                                "ja_jp": "小程序及应用",,                                "zh_cn": "小程序及应用",                            },                        },,                        {,                            "children": [,                                {,                                    "id": "6883005086914625538",,                                    "name": {,                                        "en_us": "消息提醒",,                                        "ja_jp": "消息提醒",,                                        "zh_cn": "消息提醒",                                    },                                },,                                {,                                    "id": "6883005092723802114",,                                    "name": {,                                        "en_us": "其他",,                                        "ja_jp": "其他",,                                        "zh_cn": "其他",                                    },                                },                            ],,                            "id": "6883005085605986306",,                            "name": {,                                "en_us": "聊天和群组",,                                "ja_jp": "聊天和群组",,                                "zh_cn": "聊天和群组",                            },                        },,                    ],,                }"
    category: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # rule type，1-知识库，2-工单信息，3-用户飞书信息, 示例值：1


@attr.s
class CreateHelpdeskAgentSkillReq(object):
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 技能名, 示例值："test-skill"
    rules: typing.List[CreateHelpdeskAgentSkillReqRule] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 技能rules
    agent_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服 ids


@attr.s
class CreateHelpdeskAgentSkillResp(object):
    agent_skill_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服技能id


def _gen_create_helpdesk_agent_skill_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateHelpdeskAgentSkillResp,
        scope="Helpdesk",
        api="CreateHelpdeskAgentSkill",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skills",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomBuildingIDReq(object):
    custom_building_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于查询指定建筑物的租户自定义建筑ID


@attr.s
class BatchGetMeetingRoomBuildingIDRespBuilding(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物ID
    custom_building_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义建筑物ID


@attr.s
class BatchGetMeetingRoomBuildingIDResp(object):
    buildings: BatchGetMeetingRoomBuildingIDRespBuilding = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 建筑列表


def _gen_batch_get_meeting_room_building_id_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomBuildingIDResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomBuildingID",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/building/batch_get_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteTaskReminderReq(object):
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："83912691-2e43-47fc-94a4-d512e03984fa"
    reminder_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务提醒时间设置的 ID（即 reminder.id）, 示例值："1"


@attr.s
class DeleteTaskReminderResp(object):
    pass


def _gen_delete_task_reminder_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteTaskReminderResp,
        scope="Task",
        api="DeleteTaskReminder",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/reminders/:reminder_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response
from pylark.api_service_auth_tenant_access_token_get import (
    _get_tenant_access_token,
    TokenExpire,
)
from pylark.api_service_auth_app_access_token_get import _get_app_access_token

from pylark.api_service_auth_app_ticket_resend import (
    ResendAppTicketReq,
    ResendAppTicketResp,
    _gen_resend_app_ticket_req,
)
from pylark.api_service_auth_access_token_get import (
    GetAccessTokenReq,
    GetAccessTokenResp,
    _gen_get_access_token_req,
)
from pylark.api_service_auth_access_token_refresh import (
    RefreshAccessTokenReq,
    RefreshAccessTokenResp,
    _gen_refresh_access_token_req,
)
from pylark.api_service_auth_user_info_get import (
    GetUserInfoReq,
    GetUserInfoResp,
    _gen_get_user_info_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkAuthService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_app_ticket(self) -> str:
        # genISVAppTicketKey(r.cli.appSecret)
        return self.cli.store.get()

    def set_app_ticket(self):
        # genISVAppTicketKey(r.cli.appID), appTicket, time.Hour * 2
        self.cli.store.set()

    def resend_app_ticket(
        self, request: ResendAppTicketReq, options: typing.List[str] = None
    ) -> typing.Tuple[ResendAppTicketResp, Response]:
        return self.cli.raw_request(_gen_resend_app_ticket_req(request, options))

    def get_access_token(
        self, request: GetAccessTokenReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAccessTokenResp, Response]:
        return self.cli.raw_request(_gen_get_access_token_req(request, options))

    def refresh_access_token(
        self, request: RefreshAccessTokenReq, options: typing.List[str] = None
    ) -> typing.Tuple[RefreshAccessTokenResp, Response]:
        return self.cli.raw_request(_gen_refresh_access_token_req(request, options))

    def get_user_info(
        self, request: GetUserInfoReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetUserInfoResp, Response]:
        return self.cli.raw_request(_gen_get_user_info_req(request, options))

    def get_tenant_access_token(self) -> typing.Tuple[TokenExpire, Response]:
        return _get_tenant_access_token(
            cli=self.cli,
            is_isv=False,
            app_id=self.cli.app_id,
            app_secret=self.cli.app_secret,
            tenant_key="",
        )

    def get_app_access_token(self) -> typing.Tuple[TokenExpire, Response]:
        return _get_app_access_token(
            cli=self.cli,
            is_isv=False,
            app_id=self.cli.app_id,
            app_secret=self.cli.app_secret,
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveFolderChildrenReq(object):
    types: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 需要查询的文件类型，默认返回所有 children；types 可多选，可选类型有 doc、sheet、file、folder 。如 url?types=folder&types=sheet
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件夹的 token，获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)


@attr.s
class GetDriveFolderChildrenRespChildren(object):
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件的 token
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件的标题
    type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件的类型


@attr.s
class GetDriveFolderChildrenResp(object):
    parent_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹的 token
    children: GetDriveFolderChildrenRespChildren = attr.ib(
        factory=lambda: GetDriveFolderChildrenRespChildren(),
        metadata={"req_type": "json"},
    )  # 文件夹的下的文件


def _gen_get_drive_folder_children_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveFolderChildrenResp,
        scope="Drive",
        api="GetDriveFolderChildren",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/folder/:folderToken/children",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class ImportSheetReqFile(object):
    pass


@attr.s
class ImportSheetReq(object):
    file: typing.List[ImportSheetReqFile] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 需要导入的文件数据，转换成字节数组的形式，支持"xlsx","csv"格式，最大不超过20M
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名，带上文件拓展名，如"hello.csv"、"hello.xlsx"。导入后sheet的标题将去除文件拓展名，如"hello.xlsx"导入后标题为"hello"。
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 导入的文件夹token，默认导入到根目录下


@attr.s
class ImportSheetResp(object):
    ticket: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 与导入文件一一对应的凭证，用于查询文件导入的进度，详见[查询导入结果的接口](https://open.feishu.cn/document/ukTMukTMukTM/uETO2YjLxkjN24SM5YjN)


def _gen_import_sheet_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=ImportSheetResp,
        scope="Drive",
        api="ImportSheet",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/import",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationMessageTrendReqMessageType(object):
    pass


@attr.s
class GetApplicationMessageTrendReqChatType(object):
    pass


@attr.s
class GetApplicationMessageTrendReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 目标应用的 ID
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 起始时间戳（秒），时间跨度最长支持180天
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 截止时间戳（秒），时间跨度最长支持180天
    time_interval: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 步长（秒），最小步长为60秒，需满足(${time_end} - ${time_start}) / ${time_interval} <= 2*24*60
    chat_type: GetApplicationMessageTrendReqChatType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 聊天类型，大小写不敏感，p2p：私聊；group：群聊
    message_type: GetApplicationMessageTrendReqMessageType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息类型，大小写不敏感，text：文本消息；image：图片消息；card：卡片消息；post：富文本消息；share_chat：群名片


@attr.s
class GetApplicationMessageTrendRespGroupReadTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息已读用户数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息已读用户数量


@attr.s
class GetApplicationMessageTrendRespGroupRead(object):
    timestamp: GetApplicationMessageTrendRespGroupReadTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendRespGroupReceivedTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息接收群聊数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收群聊数量


@attr.s
class GetApplicationMessageTrendRespGroupReceived(object):
    timestamp: GetApplicationMessageTrendRespGroupReceivedTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendRespGroupSentTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息接收群聊数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收群聊数量


@attr.s
class GetApplicationMessageTrendRespGroupSent(object):
    timestamp: GetApplicationMessageTrendRespGroupSentTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendRespP2pReadTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息已读用户数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息已读用户数量


@attr.s
class GetApplicationMessageTrendRespP2pRead(object):
    timestamp: GetApplicationMessageTrendRespP2pReadTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendRespP2pReceivedTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息接收用户数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收用户数量


@attr.s
class GetApplicationMessageTrendRespP2pReceived(object):
    timestamp: GetApplicationMessageTrendRespP2pReceivedTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendRespP2pSentTimestamp(object):
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息接收用户数量
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收用户数量


@attr.s
class GetApplicationMessageTrendRespP2pSent(object):
    timestamp: GetApplicationMessageTrendRespP2pSentTimestamp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 时间戳（秒）


@attr.s
class GetApplicationMessageTrendResp(object):
    p2p_sent: GetApplicationMessageTrendRespP2pSent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊发送
    p2p_received: GetApplicationMessageTrendRespP2pReceived = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊接收
    p2p_read: GetApplicationMessageTrendRespP2pRead = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊已读
    group_sent: GetApplicationMessageTrendRespGroupSent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊发送
    group_received: GetApplicationMessageTrendRespGroupReceived = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊接收
    group_read: GetApplicationMessageTrendRespGroupRead = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊已读


def _gen_get_application_message_trend_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationMessageTrendResp,
        scope="Application",
        api="GetApplicationMessageTrend",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v1/app_message_trend",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class QueryAttendanceUserSettingsReqEmployeeType(object):
    pass


@attr.s
class QueryAttendanceUserSettingsReq(object):
    employee_type: QueryAttendanceUserSettingsReqEmployeeType = attr.ib(
        factory=lambda: QueryAttendanceUserSettingsReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_ids 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值：“employee_id”
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # employee_no 或 employee_id 列表，长度不超过 100


@attr.s
class QueryAttendanceUserSettingsRespUserSetting(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    face_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 人脸照片文件 ID
    face_key_update_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人脸照片更新时间，精确到秒的时间戳


@attr.s
class QueryAttendanceUserSettingsResp(object):
    user_settings: typing.List[QueryAttendanceUserSettingsRespUserSetting] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户设置信息列表


def _gen_query_attendance_user_settings_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=QueryAttendanceUserSettingsResp,
        scope="Attendance",
        api="QueryAttendanceUserSettings",
        method="GET",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_settings/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetChatAnnouncementReqUserIDType(object):
    pass


@attr.s
class GetChatAnnouncementReq(object):
    user_id_type: GetChatAnnouncementReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值: "open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`，字段权限要求: 获取用户 userid
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待获取公告的群 ID, 示例值: "oc_5ad11d72b830411d72b836c20"


@attr.s
class GetChatAnnouncementRespModifierIDType(object):
    pass


@attr.s
class GetChatAnnouncementRespOwnerIDType(object):
    pass


@attr.s
class GetChatAnnouncementResp(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 云文档序列化信息
    revision: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档当前版本号 纯数字
    create_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档生成的时间戳（秒）
    update_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档更新的时间戳（秒）
    owner_id_type: GetChatAnnouncementRespOwnerIDType = attr.ib(
        factory=lambda: GetChatAnnouncementRespOwnerIDType(),
        metadata={"req_type": "json"},
    )  # 文档所有者 ID 类型, open_id/user_id/union_id/app_id, 可选值有: `user_id`：以 user_id 来识别用户, `union_id`：以 union_id 来识别用户, `open_id`：以 open_id 来识别用户, `app_id`：以 app_id 来识别应用
    owner_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档所有者 ID
    modifier_id_type: GetChatAnnouncementRespModifierIDType = attr.ib(
        factory=lambda: GetChatAnnouncementRespModifierIDType(),
        metadata={"req_type": "json"},
    )  # 文档最新修改者 id 类型, open_id/user_id/union_id/app_id, 可选值有: `user_id`：以 user_id 来识别用户, `union_id`：以 union_id 来识别用户, `open_id`：以 open_id 来识别用户, `app_id`：以 app_id 来识别应用
    modifier_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档最新修改者 id


def _gen_get_chat_announcement_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetChatAnnouncementResp,
        scope="Chat",
        api="GetChatAnnouncement",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/announcement",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenWebAppReq(object):
    app_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # H5应用的 appId(可从「开发者后台-凭证与基础信息」获取)
    mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打开H5应用的容器模式，枚举值包括<br> `appCenter`：在工作台打开，3.20版本开始支持（缺省值） <br> `window`：在独立窗口打开，3.20版本开始支持 <br> `sidebar`：在侧边栏打开，3.40版本开始支持
    path: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 访问H5应用的具体某个页面，path参数将替换H5应用URL的path部分 <br>也可以使用 path_android、path_ios、path_pc 参数对不同的客户端指定不同的path <br>3.20版本开始支持
    path_android: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，Android 端会优先使用该参数，如果该参数不存在，则会使用 path 参数。 <br>3.20版本开始支持
    path_ios: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，iOS 端会优先使用该参数，如果该参数不存在，则会使用 path 参数 <br>3.20版本开始支持
    path_pc: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 同 path 参数，PC 端会优先使用该参数，如果该参数不存在，则会使用 path 参数 <br>3.20版本开始支持


@attr.s
class OpenWebAppResp(object):
    pass


def _gen_open_web_app_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenWebAppResp,
        scope="AppLink",
        api="OpenWebApp",
        method="",
        url="https://applink.feishu.cn/client/web_app/open",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetFloatImageReqOffsetY(object):
    pass


@attr.s
class UpdateSheetFloatImageReqOffsetX(object):
    pass


@attr.s
class UpdateSheetFloatImageReqHeight(object):
    pass


@attr.s
class UpdateSheetFloatImageReqWidth(object):
    pass


@attr.s
class UpdateSheetFloatImageReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"
    float_image_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 浮动图片 id, 示例值："ye06SS14ph"
    float_image_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 【更新时不用传，创建需要】浮动图片 token，需要先上传图片到表格获得此 token 之后再进行浮动图片的相关操作, 示例值："boxbcbQsaSqIXsxxxxx1HCPJFbh"
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 浮动图片的左上角单元格定位，只支持一个单元格, 示例值："0b**12!A1:A1"
    width: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片的宽度，大于等于 20px, 示例值：100
    height: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片的高度，大于等于 20px, 示例值：100
    offset_x: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片左上角所在位置相对于所在单元格左上角的横向偏移，大于等于0且小于所在单元格的宽度, 示例值：0
    offset_y: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片左上角所在位置相对于所在单元格左上角的纵向偏移，大于等于0且小于所在单元格的高度, 示例值：0


@attr.s
class UpdateSheetFloatImageRespFloatImageOffsetY(object):
    pass


@attr.s
class UpdateSheetFloatImageRespFloatImageOffsetX(object):
    pass


@attr.s
class UpdateSheetFloatImageRespFloatImageHeight(object):
    pass


@attr.s
class UpdateSheetFloatImageRespFloatImageWidth(object):
    pass


@attr.s
class UpdateSheetFloatImageRespFloatImage(object):
    float_image_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 浮动图片 id
    float_image_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 【更新时不用传，创建需要】浮动图片 token，需要先上传图片到表格获得此 token 之后再进行浮动图片的相关操作
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 浮动图片的左上角单元格定位，只支持一个单元格
    width: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片的宽度，大于等于 20px
    height: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片的高度，大于等于 20px
    offset_x: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片左上角所在位置相对于所在单元格左上角的横向偏移，大于等于0且小于所在单元格的宽度
    offset_y: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片左上角所在位置相对于所在单元格左上角的纵向偏移，大于等于0且小于所在单元格的高度


@attr.s
class UpdateSheetFloatImageResp(object):
    float_image: UpdateSheetFloatImageRespFloatImage = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 浮动图片信息


def _gen_update_sheet_float_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetFloatImageResp,
        scope="Drive",
        api="UpdateSheetFloatImage",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/float_images/:float_image_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireReferralByApplicationReqUserIDType(object):
    pass


@attr.s
class GetHireReferralByApplicationReq(object):
    application_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 投递的id, 示例值："6134134355464633"
    user_id_type: GetHireReferralByApplicationReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid


@attr.s
class GetHireReferralByApplicationRespReferral(object):
    application_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递id
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间（ms）
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 内推的id
    referral_user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 内推人的id


@attr.s
class GetHireReferralByApplicationResp(object):
    referral: GetHireReferralByApplicationRespReferral = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 内推信息


def _gen_get_hire_referral_by_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireReferralByApplicationResp,
        scope="Hire",
        api="GetHireReferralByApplication",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/referrals/get_by_application",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetDataValidationDropdownReqDataValidationOptions(object):
    multiple_values: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单选填false, 多选填true，不填默认为false
    highlight_valid_data: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否设置颜色和胶囊样式, 不填默认为false
    colors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 当highlightValidData为true时，color需填颜色,与conditionValues中的值一一对应。需是RGB16进制格式,如"#fffd00"


@attr.s
class UpdateSheetDataValidationDropdownReqDataValidation(object):
    condition_values: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 下拉列表选项值, 需为字符串,不能包含","，选项值最长100字符,选项个数最多500个
    options: UpdateSheetDataValidationDropdownReqDataValidationOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可选属性


@attr.s
class UpdateSheetDataValidationDropdownReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    sheet_id: str = attr.ib(default="", metadata={"req_type": "path"})  # 子sheet唯一识别参数
    data_validation_id: int = attr.ib(
        default=0, metadata={"req_type": "path"}
    )  # sheet中下拉列表的唯一标示id
    data_validation_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下拉列表填"list"
    data_validation: UpdateSheetDataValidationDropdownReqDataValidation = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 下拉列表规则属性


@attr.s
class UpdateSheetDataValidationDropdownRespDataValidationOptionsColorValueMap(object):
    pass


@attr.s
class UpdateSheetDataValidationDropdownRespDataValidationOptions(object):
    multiple_values: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单选填false, 多选填true
    highlight_valid_data: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否设置颜色和胶囊样式
    color_value_map: UpdateSheetDataValidationDropdownRespDataValidationOptionsColorValueMap = attr.ib(
        factory=lambda: UpdateSheetDataValidationDropdownRespDataValidationOptionsColorValueMap(),
        metadata={"req_type": "json"},
    )  # 当highlightValidData为true时，colorValueMap的key与conditionValues中的值一一对应，value为对应的颜色参数。


@attr.s
class UpdateSheetDataValidationDropdownRespDataValidation(object):
    data_validation_id: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 唯一标示id
    data_validation_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下拉列表为"list"
    condition_values: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 下拉列表选项值
    options: UpdateSheetDataValidationDropdownRespDataValidationOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可选属性


@attr.s
class UpdateSheetDataValidationDropdownResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet的token
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作表 sheet 的 id
    data_validation: UpdateSheetDataValidationDropdownRespDataValidation = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


def _gen_update_sheet_data_validation_dropdown_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetDataValidationDropdownResp,
        scope="Drive",
        api="UpdateSheetDataValidationDropdown",
        method="PUT",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dataValidation/:sheetId/:dataValidationId",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetChatMemberListReqMemberIDType(object):
    pass


@attr.s
class GetChatMemberListReq(object):
    member_id_type: GetChatMemberListReqMemberIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 群成员 id 类型 open_id/user_id/union_id, 示例值："user_id", 可选值有: `user_id`：以 user_id 来识别成员, `union_id`：以 union_id 来识别成员, `open_id`：以 open_id 来识别成员
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："dmJCRHhpd3JRbGV1VEVNRFFyTitRWDY5ZFkybmYrMEUwMUFYT0VMMWdENEtuYUhsNUxGMDIwemtvdE5ORjBNQQ=="
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID, 示例值："oc_a0553eda9014c201e6969b478895c230"


@attr.s
class GetChatMemberListRespItemMemberIDType(object):
    pass


@attr.s
class GetChatMemberListRespItem(object):
    member_id_type: GetChatMemberListRespItemMemberIDType = attr.ib(
        factory=lambda: GetChatMemberListRespItemMemberIDType(),
        metadata={"req_type": "json"},
    )  # member id 类型
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # member id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名字


@attr.s
class GetChatMemberListResp(object):
    items: typing.List[GetChatMemberListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # member 列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_chat_member_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetChatMemberListResp,
        scope="Chat",
        api="GetChatMemberList",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/members",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateBitableRecordReqFieldsValue(object):
    pass


@attr.s
class UpdateBitableRecordReqFields(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名, 示例值："多行文本"
    value: typing.Any = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 内容, 示例值：文本


@attr.s
class UpdateBitableRecordReqUserIDType(object):
    pass


@attr.s
class UpdateBitableRecordReq(object):
    user_id_type: UpdateBitableRecordReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblsRc9GRRXKqhvW"
    record_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 单条记录的 id, 示例值："recqwIwhc6"
    fields: UpdateBitableRecordReqFields = attr.ib(
        factory=lambda: UpdateBitableRecordReqFields(), metadata={"req_type": "json"}
    )  # 记录字段


@attr.s
class UpdateBitableRecordRespRecordFieldsValue(object):
    pass


@attr.s
class UpdateBitableRecordRespRecordFields(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名
    value: typing.Any = attr.ib(default=None, metadata={"req_type": "json"})  # 内容


@attr.s
class UpdateBitableRecordRespRecord(object):
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 记录 id
    fields: UpdateBitableRecordRespRecordFields = attr.ib(
        factory=lambda: UpdateBitableRecordRespRecordFields(),
        metadata={"req_type": "json"},
    )  # 记录字段


@attr.s
class UpdateBitableRecordResp(object):
    record: UpdateBitableRecordRespRecord = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # {,    "fields": {,        "人力评估": 2,,        "任务执行人": [,            {,                "id": "ou_debc524b2d8cb187704df652b43d29de",            },        ],,        "任务描述": "多渠道收集用户反馈",,        "对应 OKR": [,            "recqwIwhc6",,            "recOuEJMvN",        ],,        "截止日期": 1609516800000,,        "是否完成": true,,        "状态": "已结束",,        "相关部门": [,            "销售",,            "客服",        ],    },}


def _gen_update_bitable_record_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateBitableRecordResp,
        scope="Bitable",
        api="UpdateBitableRecord",
        method="PUT",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/records/:record_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_acs_access_record_photo_get import (
    GetACSAccessRecordPhotoReq,
    GetACSAccessRecordPhotoResp,
    _gen_get_acs_access_record_photo_req,
)
from pylark.api_service_acs_access_record_list import (
    GetACSAccessRecordListReq,
    GetACSAccessRecordListResp,
    _gen_get_acs_access_record_list_req,
)
from pylark.api_service_acs_device_list import (
    GetACSDeviceListReq,
    GetACSDeviceListResp,
    _gen_get_acs_device_list_req,
)
from pylark.api_service_acs_user_face_get import (
    GetACSUserFaceReq,
    GetACSUserFaceResp,
    _gen_get_acs_user_face_req,
)
from pylark.api_service_acs_user_face_update import (
    UpdateACSUserFaceReq,
    UpdateACSUserFaceResp,
    _gen_update_acs_user_face_req,
)
from pylark.api_service_acs_user_get import (
    GetACSUserReq,
    GetACSUserResp,
    _gen_get_acs_user_req,
)
from pylark.api_service_acs_user_update import (
    UpdateACSUserReq,
    UpdateACSUserResp,
    _gen_update_acs_user_req,
)
from pylark.api_service_acs_user_list import (
    GetACSUserListReq,
    GetACSUserListResp,
    _gen_get_acs_user_list_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkACSService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_acs_access_record_photo(
        self, request: GetACSAccessRecordPhotoReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSAccessRecordPhotoResp, Response]:
        return self.cli.raw_request(
            _gen_get_acs_access_record_photo_req(request, options)
        )

    def get_acs_access_record_list(
        self, request: GetACSAccessRecordListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSAccessRecordListResp, Response]:
        return self.cli.raw_request(
            _gen_get_acs_access_record_list_req(request, options)
        )

    def get_acs_device_list(
        self, request: GetACSDeviceListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSDeviceListResp, Response]:
        return self.cli.raw_request(_gen_get_acs_device_list_req(request, options))

    def get_acs_user_face(
        self, request: GetACSUserFaceReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSUserFaceResp, Response]:
        return self.cli.raw_request(_gen_get_acs_user_face_req(request, options))

    def update_acs_user_face(
        self, request: UpdateACSUserFaceReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateACSUserFaceResp, Response]:
        return self.cli.raw_request(_gen_update_acs_user_face_req(request, options))

    def get_acs_user(
        self, request: GetACSUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSUserResp, Response]:
        return self.cli.raw_request(_gen_get_acs_user_req(request, options))

    def update_acs_user(
        self, request: UpdateACSUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateACSUserResp, Response]:
        return self.cli.raw_request(_gen_update_acs_user_req(request, options))

    def get_acs_user_list(
        self, request: GetACSUserListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetACSUserListResp, Response]:
        return self.cli.raw_request(_gen_get_acs_user_list_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_okr_period_get_list import (
    GetOKRPeriodListReq,
    GetOKRPeriodListResp,
    _gen_get_okr_period_list_req,
)
from pylark.api_service_okr_okr_batch_get import (
    BatchGetOKRReq,
    BatchGetOKRResp,
    _gen_batch_get_okr_req,
)
from pylark.api_service_okr_user_okr_get_list import (
    GetUserOKRListReq,
    GetUserOKRListResp,
    _gen_get_user_okr_list_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkOKRService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_okr_period_list(
        self, request: GetOKRPeriodListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetOKRPeriodListResp, Response]:
        return self.cli.raw_request(_gen_get_okr_period_list_req(request, options))

    def batch_get_okr(
        self, request: BatchGetOKRReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetOKRResp, Response]:
        return self.cli.raw_request(_gen_batch_get_okr_req(request, options))

    def get_user_okr_list(
        self, request: GetUserOKRListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetUserOKRListResp, Response]:
        return self.cli.raw_request(_gen_get_user_okr_list_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSheetDataValidationDropdownReqDataValidationRange(object):
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    data_validation_ids: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 指定需要删除的dataValidationIds


@attr.s
class DeleteSheetDataValidationDropdownReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    data_validation_ranges: typing.List[
        DeleteSheetDataValidationDropdownReqDataValidationRange
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 范围数组，每个range 最大单元格数量5000，每个range独立执行，一个range的失败不影响其他range的执行。返回结果会返回每个range的执行结果


@attr.s
class DeleteSheetDataValidationDropdownRespRangeResult(object):
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 执行的range,与请求入参中的range 对应
    msg: str = attr.ib(default="", metadata={"req_type": "json"})  # 结果信息
    success: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 执行结果
    updated_cells: int = attr.ib(default=0, metadata={"req_type": "json"})  # 影响的单元格数量


@attr.s
class DeleteSheetDataValidationDropdownResp(object):
    range_results: typing.List[
        DeleteSheetDataValidationDropdownRespRangeResult
    ] = attr.ib(factory=lambda: [], metadata={"req_type": "json"})


def _gen_delete_sheet_data_validation_dropdown_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSheetDataValidationDropdownResp,
        scope="Drive",
        api="DeleteSheetDataValidationDropdown",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dataValidation",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserTaskReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserTaskReq(object):
    employee_type: GetAttendanceUserTaskReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserTaskReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_ids 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值：“employee_id”
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # employee_no 或 employee_id 列表
    check_date_from: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询的起始工作日
    check_date_to: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 查询的结束工作日，与 check_date_from 的时间间隔不超过30天


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLatitude(object):
    pass


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLongitude(object):
    pass


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecord(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    creator_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡记录创建者的 employee_no
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡位置名称信息
    check_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡时间，精确到秒的时间戳
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡备注
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡记录 ID
    longitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡经度
    latitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡纬度
    ssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 SSID
    bssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 MAC 地址
    is_field: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为外勤打卡
    is_wifi: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为 Wi-Fi 打卡
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 记录生成方式，可用值：【0（用户自己打卡），1（管理员修改），2（用户补卡），3（系统自动生成），4（下班免打卡），5（考勤机打卡），6（极速打卡），7（考勤开放平台导入），8（飞书自研考勤机），9（飞书门禁考勤机）】
    photo_urls: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡照片列表
    device_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机打卡设备ID


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLatitude(object):
    pass


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLongitude(object):
    pass


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecord(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    creator_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡记录创建者的 employee_no
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡位置名称信息
    check_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡时间，精确到秒的时间戳
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡备注
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡记录 ID
    longitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡经度
    latitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡纬度
    ssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 SSID
    bssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 MAC 地址
    is_field: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为外勤打卡
    is_wifi: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为 Wi-Fi 打卡
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 记录生成方式，可用值：【0（用户自己打卡），1（管理员修改），2（用户补卡），3（系统自动生成），4（下班免打卡），5（考勤机打卡），6（极速打卡），7（考勤开放平台导入），8（飞书自研考勤机），9（飞书门禁考勤机）】
    photo_urls: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡照片列表
    device_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机打卡设备ID


@attr.s
class GetAttendanceUserTaskRespUserTaskResultRecord(object):
    check_in_record_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上班打卡记录 ID
    check_in_record: GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecord = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 上班打卡记录
    check_out_record_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下班打卡记录 ID
    check_out_record: GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecord = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 下班打卡记录
    check_in_result: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上班打卡结果，可用值：【NoNeedCheck（无需打卡），SystemCheck（系统打卡），Normal（正常），Early（早退），Late（迟到），Lack（缺卡）】
    check_out_result: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下班打卡结果，可用值：【NoNeedCheck（无需打卡），SystemCheck（系统打卡），Normal（正常），Early（早退），Late（迟到），Lack（缺卡）】
    check_in_result_supplement: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上班打卡结果补充，可用值：【None（无），ManagerModification（管理员修改），CardReplacement（补卡通过），ShiftChange（换班），Travel（出差），Leave（请假），GoOut（外出），CardReplacementApplication（补卡申请中），FieldPunch（外勤打卡）】
    check_out_result_supplement: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下班打卡结果补充，可用值：【None（无），ManagerModification（管理员修改），CardReplacement（补卡通过），ShiftChange（换班），Travel（出差），Leave（请假），GoOut（外出），CardReplacementApplication（补卡申请中），FieldPunch（外勤打卡）】


@attr.s
class GetAttendanceUserTaskRespUserTaskResult(object):
    result_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡记录 ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # employee ID
    employee_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # employee 姓名
    day: int = attr.ib(default=0, metadata={"req_type": "json"})  # 日期
    group_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组 ID
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID
    records: typing.List[GetAttendanceUserTaskRespUserTaskResultRecord] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户考勤记录


@attr.s
class GetAttendanceUserTaskResp(object):
    user_task_results: typing.List[GetAttendanceUserTaskRespUserTaskResult] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡任务列表


def _gen_get_attendance_user_task_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserTaskResp,
        scope="Attendance",
        api="GetAttendanceUserTask",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_tasks/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMessageListReqContainerIDType(object):
    pass


@attr.s
class GetMessageListReq(object):
    container_id_type: GetMessageListReqContainerIDType = attr.ib(
        factory=lambda: GetMessageListReqContainerIDType(),
        metadata={"req_type": "query"},
    )  # 容器类型 ，目前可选值仅有"chat", 示例值："chat"
    container_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 容器的id，即chat的id, 示例值："oc_234jsi43d3ssi993d43545f"
    start_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 历史信息的起始时间, 示例值："1609296809"
    end_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 历史信息的结束时间, 示例值："1608594809"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："GxmvlNRvP0NdQZpa7yIqf_Lv_QuBwTQ8tXkX7w-irAghVD_TvuYd1aoJ1LQph86O-XImC4X9j9FhUPhXQDvtrQ=="
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`50`


@attr.s
class GetMessageListRespItemMentionIDType(object):
    pass


@attr.s
class GetMessageListRespItemMention(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # mention key
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户open id
    id_type: GetMessageListRespItemMentionIDType = attr.ib(
        factory=lambda: GetMessageListRespItemMentionIDType(),
        metadata={"req_type": "json"},
    )  # id 可以是open_id，user_id或者union_id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 被at用户的姓名


@attr.s
class GetMessageListRespItemBody(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息jsonContent


@attr.s
class GetMessageListRespItemSenderIDType(object):
    pass


@attr.s
class GetMessageListRespItemSender(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的id
    id_type: GetMessageListRespItemSenderIDType = attr.ib(
        factory=lambda: GetMessageListRespItemSenderIDType(),
        metadata={"req_type": "json"},
    )  # 该字段标识发送者的id类型
    sender_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的类型


@attr.s
class GetMessageListRespItemMsgType(object):
    pass


@attr.s
class GetMessageListRespItem(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息id open_message_id
    root_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 根消息id open_message_id
    parent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父消息的id open_message_id
    msg_type: GetMessageListRespItemMsgType = attr.ib(
        factory=lambda: GetMessageListRespItemMsgType(), metadata={"req_type": "json"}
    )  # 消息类型 text post card image等等
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息生成的时间戳(毫秒)
    update_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息更新的时间戳
    deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被撤回
    updated: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被更新
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 所属的群
    sender: GetMessageListRespItemSender = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 发送者，可以是用户或应用
    body: GetMessageListRespItemBody = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息内容，json结构，格式说明参考： [消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/events/message_content)
    mentions: typing.List[GetMessageListRespItemMention] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被艾特的人或应用的id
    upper_message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上一层级的消息id open_message_id


@attr.s
class GetMessageListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetMessageListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # message[]


def _gen_get_message_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMessageListResp,
        scope="Message",
        api="GetMessageList",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/messages",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_approval_approval_get import (
    GetApprovalReq,
    GetApprovalResp,
    _gen_get_approval_req,
)
from pylark.api_service_approval_instance_list import (
    GetApprovalInstanceListReq,
    GetApprovalInstanceListResp,
    _gen_get_approval_instance_list_req,
)
from pylark.api_service_approval_instance_get import (
    GetApprovalInstanceReq,
    GetApprovalInstanceResp,
    _gen_get_approval_instance_req,
)
from pylark.api_service_approval_instance_create import (
    CreateApprovalInstanceReq,
    CreateApprovalInstanceResp,
    _gen_create_approval_instance_req,
)
from pylark.api_service_approval_instance_approve import (
    ApproveApprovalInstanceReq,
    ApproveApprovalInstanceResp,
    _gen_approve_approval_instance_req,
)
from pylark.api_service_approval_instance_reject import (
    RejectApprovalInstanceReq,
    RejectApprovalInstanceResp,
    _gen_reject_approval_instance_req,
)
from pylark.api_service_approval_instance_transfer import (
    TransferApprovalInstanceReq,
    TransferApprovalInstanceResp,
    _gen_transfer_approval_instance_req,
)
from pylark.api_service_approval_instance_cancel import (
    CancelApprovalInstanceReq,
    CancelApprovalInstanceResp,
    _gen_cancel_approval_instance_req,
)
from pylark.api_service_approval_file_upload import (
    UploadApprovalFileReq,
    UploadApprovalFileResp,
    _gen_upload_approval_file_req,
)
from pylark.api_service_approval_instance_search import (
    SearchApprovalInstanceReq,
    SearchApprovalInstanceResp,
    _gen_search_approval_instance_req,
)
from pylark.api_service_approval_task_search import (
    SearchApprovalTaskReq,
    SearchApprovalTaskResp,
    _gen_search_approval_task_req,
)
from pylark.api_service_approval_carbon_copy_search import (
    SearchApprovalCarbonCopyReq,
    SearchApprovalCarbonCopyResp,
    _gen_search_approval_carbon_copy_req,
)
from pylark.api_service_approval_carbon_copy_create import (
    CreateApprovalCarbonCopyReq,
    CreateApprovalCarbonCopyResp,
    _gen_create_approval_carbon_copy_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkApprovalService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_approval(
        self, request: GetApprovalReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApprovalResp, Response]:
        return self.cli.raw_request(_gen_get_approval_req(request, options))

    def get_approval_instance_list(
        self, request: GetApprovalInstanceListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApprovalInstanceListResp, Response]:
        return self.cli.raw_request(
            _gen_get_approval_instance_list_req(request, options)
        )

    def get_approval_instance(
        self, request: GetApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApprovalInstanceResp, Response]:
        return self.cli.raw_request(_gen_get_approval_instance_req(request, options))

    def create_approval_instance(
        self, request: CreateApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateApprovalInstanceResp, Response]:
        return self.cli.raw_request(_gen_create_approval_instance_req(request, options))

    def approve_approval_instance(
        self, request: ApproveApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[ApproveApprovalInstanceResp, Response]:
        return self.cli.raw_request(
            _gen_approve_approval_instance_req(request, options)
        )

    def reject_approval_instance(
        self, request: RejectApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[RejectApprovalInstanceResp, Response]:
        return self.cli.raw_request(_gen_reject_approval_instance_req(request, options))

    def transfer_approval_instance(
        self, request: TransferApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[TransferApprovalInstanceResp, Response]:
        return self.cli.raw_request(
            _gen_transfer_approval_instance_req(request, options)
        )

    def cancel_approval_instance(
        self, request: CancelApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[CancelApprovalInstanceResp, Response]:
        return self.cli.raw_request(_gen_cancel_approval_instance_req(request, options))

    def upload_approval_file(
        self, request: UploadApprovalFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadApprovalFileResp, Response]:
        return self.cli.raw_request(_gen_upload_approval_file_req(request, options))

    def search_approval_instance(
        self, request: SearchApprovalInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchApprovalInstanceResp, Response]:
        return self.cli.raw_request(_gen_search_approval_instance_req(request, options))

    def search_approval_task(
        self, request: SearchApprovalTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchApprovalTaskResp, Response]:
        return self.cli.raw_request(_gen_search_approval_task_req(request, options))

    def search_approval_carbon_copy(
        self, request: SearchApprovalCarbonCopyReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchApprovalCarbonCopyResp, Response]:
        return self.cli.raw_request(
            _gen_search_approval_carbon_copy_req(request, options)
        )

    def create_approval_carbon_copy(
        self, request: CreateApprovalCarbonCopyReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateApprovalCarbonCopyResp, Response]:
        return self.cli.raw_request(
            _gen_create_approval_carbon_copy_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UnsubscribeHelpdeskEventReqEvent(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 事件类型, 示例值："helpdesk.ticket_message"
    subtype: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 事件子类型, 示例值："ticket_message.created_v1"


@attr.s
class UnsubscribeHelpdeskEventReq(object):
    events: typing.List[UnsubscribeHelpdeskEventReqEvent] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # event list to unsubscribe


@attr.s
class UnsubscribeHelpdeskEventResp(object):
    pass


def _gen_unsubscribe_helpdesk_event_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UnsubscribeHelpdeskEventResp,
        scope="Helpdesk",
        api="UnsubscribeHelpdeskEvent",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/events/unsubscribe",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetDriveMediaTmpDownloadURLReq(object):
    file_tokens: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 文件标识符列表, 示例值：boxcnabcdefg
    extra: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 拓展信息(可选), 示例值："[请参考-上传点类型及对应Extra说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/drive-v1/media/introduction)"


@attr.s
class BatchGetDriveMediaTmpDownloadURLRespTmpDownloadURL(object):
    file_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件标识符
    tmp_download_url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件临时下载链接


@attr.s
class BatchGetDriveMediaTmpDownloadURLResp(object):
    tmp_download_urls: typing.List[
        BatchGetDriveMediaTmpDownloadURLRespTmpDownloadURL
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 临时下载列表


def _gen_batch_get_drive_media_tmp_download_url_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetDriveMediaTmpDownloadURLResp,
        scope="Drive",
        api="BatchGetDriveMediaTmpDownloadURL",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/medias/batch_get_tmp_download_url",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationUsageDetailReqFilter(object):
    key: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 过滤字段，支持`department_id`
    op: str = attr.ib(default="", metadata={"req_type": "json"})  # 过滤操作，支持`in`、`=`
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 过滤字段值，多个使用英文逗号分隔


@attr.s
class GetApplicationUsageDetailReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 目标应用的 ID，支持自建应用
    ability: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用能力，mp：小程序
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 起始时间戳（秒），时间跨度最长支持180天
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 截止时间戳（秒），时间跨度最长支持180天
    filters: typing.List[GetApplicationUsageDetailReqFilter] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 过滤条件
    order_by: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 排序字段，大小写不敏感，支持open_id、timestamp，默认为open_id
    order: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 排序方式，大小写不敏感，desc：降序；asc：升序，默认值
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，首次传空，非首次使用返回中的page_token
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 分页大小，默认为512，取值区间[1,1000]


@attr.s
class GetApplicationUsageDetailRespUser(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # open_id


@attr.s
class GetApplicationUsageDetailResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多分页，当 has_more 为 true 时，会同时返回新的 page_token
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    users: typing.List[GetApplicationUsageDetailRespUser] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户列表


def _gen_get_application_usage_detail_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationUsageDetailResp,
        scope="Application",
        api="GetApplicationUsageDetail",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v1/app_usage_detail",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_bot_info import (
    GetBotInfoReq,
    GetBotInfoResp,
    _gen_get_bot_info_req,
)
from pylark.api_service_bot_add import (
    AddBotToChatReq,
    AddBotToChatResp,
    _gen_add_bot_to_chat_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkBotService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_bot_info(
        self, request: GetBotInfoReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBotInfoResp, Response]:
        return self.cli.raw_request(_gen_get_bot_info_req(request, options))

    def add_bot_to_chat(
        self, request: AddBotToChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[AddBotToChatResp, Response]:
        return self.cli.raw_request(_gen_add_bot_to_chat_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class TerminateHireApplicationReq(object):
    application_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 投递ID, 示例值："12312312312"
    termination_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 终止原因的类型, 示例值：1, 可选值有: `1`：我们拒绝了候选人, `22`：候选人拒绝了我们, `27`：其他
    termination_reason_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 终止的具体原因的id列表
    termination_reason_note: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 终止备注, 示例值："不符合期望"


@attr.s
class TerminateHireApplicationResp(object):
    pass


def _gen_terminate_hire_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=TerminateHireApplicationResp,
        scope="Hire",
        api="TerminateHireApplication",
        method="POST",
        url="https://open.feishu.cn/open-apis/hire/v1/applications/:application_id/terminate",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateSheetProtectedDimensionReqAddProtectedDimensionDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认 ROWS ，可选 ROWS、COLUMNS
    start_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 开始的位置
    end_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 结束的位置


@attr.s
class CreateSheetProtectedDimensionReqAddProtectedDimension(object):
    dimension: CreateSheetProtectedDimensionReqAddProtectedDimensionDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要保护行列的维度信息
    editors: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 允许编辑保护范围的用户的 userID
    users: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 允许编辑保护范围的用户的id，id类型取决于user_id_type
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围的信息


@attr.s
class CreateSheetProtectedDimensionReqUserIDType(object):
    pass


@attr.s
class CreateSheetProtectedDimensionReq(object):
    user_id_type: CreateSheetProtectedDimensionReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 请求的用户id类型，可选open_id,union_id
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    add_protected_dimension: CreateSheetProtectedDimensionReqAddProtectedDimension = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 需要增加保护范围的维度信息，可多个范围


@attr.s
class CreateSheetProtectedDimensionRespAddProtectedDimensionDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认 ROWS ，可选 ROWS、COLUMNS
    start_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 开始的位置
    end_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 结束的位置


@attr.s
class CreateSheetProtectedDimensionRespAddProtectedDimension(object):
    dimension: CreateSheetProtectedDimensionRespAddProtectedDimensionDimension = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 需要保护行列的维度信息
    editors: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 允许编辑保护范围的用户的 userID
    users: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 允许编辑保护范围的用户的id，id类型取决于user_id_type
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围的信息
    protect_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 保护区域的唯一 uid ，可用做后续解除保护


@attr.s
class CreateSheetProtectedDimensionResp(object):
    add_protected_dimension: CreateSheetProtectedDimensionRespAddProtectedDimension = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 需要增加保护范围的维度信息，可多个范围


def _gen_create_sheet_protected_dimension_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateSheetProtectedDimensionResp,
        scope="Drive",
        api="CreateSheetProtectedDimension",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/protected_dimension",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveMemberPermissionReq(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 权限客体类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：电子表格, `file`：云空间文件, `wiki`：知识库节点（暂不支持）, `bitable`：多维表格, `docx`：文档
    need_notification: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 添加权限后是否通知对方, 示例值：false, 默认值: `false`
    token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 权限客体token, 示例值："doccnBKgoMyY5OMbUG6FioTXuBe"
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，可选值有：, `email`: 飞书企业邮箱, `openid`: 开放平台ID, `openchat`: 开放平台群组, `opendepartmentid`: 开放平台部门ID, `userid`: 用户自定义ID, 示例值："openid"
    member_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型下的值, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    perm: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要增加的权限，可选值有：, `view`: 可阅读, `edit`: 可编辑, `full_access`: 所有权限, 示例值："view"


@attr.s
class CreateDriveMemberPermissionRespMember(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，可选值有：, `email`: 飞书企业邮箱, `openid`: 开放平台ID, `openchat`: 开放平台群组, `opendepartmentid`: 开放平台部门ID, `userid`: 用户自定义ID
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型下的值
    perm: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要增加的权限，可选值有：, `view`: 可阅读, `edit`: 可编辑, `full_access`: 所有权限


@attr.s
class CreateDriveMemberPermissionResp(object):
    member: CreateDriveMemberPermissionRespMember = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 本次添加权限的用户信息


def _gen_create_drive_member_permission_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveMemberPermissionResp,
        scope="Drive",
        api="CreateDriveMemberPermission",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/permissions/:token/members",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
